% Pole Placement Design for Magnetic Suspension
clear all;

% =============================================
% Pole Placement Design for Magnetic Suspension
% =============================================
% Model Parameters
Km = 1E-4;
d = 0.04;
m = 0.1;
g = 10;
i0 = sqrt(m*g/Km)*d/2;
Ki = 2*Km*i0/(d/2)^2;
Kx = 2*Km*i0^2/(d/2)^3;

% ======================================
% Pole Placement without Integrator and filter
% ======================================
% Inner Loop
l2 = 0;
l1 = 1000;
l0 = 30000;
p2 = 0;
p1 = 130000;
p0 = 3100000;
% Filter
R0 = 1;
f0 = 1;
f1 = 0; 
f2 = 0;
% reference tracking
ref = d/4;
d_load = 0;
% simulation
options = simset('Solver','ode23s');
sim('ECE441_Ex7_solution',[0,20],options);
figure(1);
plot(t_magnet,y,t_magnet,d/4);
legend('reference step $x = d/4$','reference value d/4')
grid
xlabel('time [sec]')
ylabel('potition [m/s]')

% disturbance rejection
ref = 0;
d_load = 0.05;
sim('ECE441_Ex7_solution',[0,20],options);
figure(2);
plot(t_magnet,y);
legend('disturbance step $F_\mathrm{L} = 0.5 N$')
grid
xlabel('time [sec]')
ylabel('position [m/s]')

% ======================================
% Pole Placement without Integrator and wth filter
% ======================================
% Inner Loop
l2 = 0;
l1 = 1000;
l0 = 30000;
p2 = 0;
p1 = 130000;
p0 = 3100000;
% Filter
R0 = 10;
f0 = 310;
f1 = 13; 
f2 = 0;
% reference tracking
ref = d/4;
d_load = 0;
% simulation
options = simset('Solver','ode23s');
sim('ECE441_Ex7_solution',[0,20],options);
figure(3);
plot(t_magnet,y,t_magnet,d/4);
legend('reference step $x = d/4$','reference value d/4')
grid
xlabel('time [sec]')
ylabel('potition [m/s]')
% disturbance rejection
ref = 0;
d_load = 0.05;
sim('ECE441_Ex7_solution',[0,20],options);
figure(4);
plot(t_magnet,y);
legend('disturbance step $F_\mathrm{L} = 0.5 N$')
grid
xlabel('time [sec]')
ylabel('position [m/s]')
